@@ -1,13 +1,13 @@
 //!
 //! # KK
 //!
-//! **K**eep correct, **K**eep reliable.
+//! **K**eep it correct, **K**eep it reliable.
 //!
 //! Lightweight private-cloud solution for SME scenarios.
 //!
 
 #![warn(missing_docs, unused_import_braces, unused_extern_crates)]
 
+pub mod ctrl;
 pub mod err;
-pub mod master;
 pub mod model;
